import { DecimalPipe } from '@angular/common';
import { Pipe, PipeTransform } from '@angular/core';
import { convertSeconds } from '@pv-frontend/pv-shared-services/utils/time';

@Pipe({
  name: 'countdownFormat',
  pure: true,
})
export class PvCountdownFormatPipe implements PipeTransform {
  public constructor(private decimalPipe: DecimalPipe) {}

  public transform(
    secondsValue: number,
    showZeroHours: boolean = false,
    showZeroMinutes: boolean = true,
    showSuffix?: boolean
  ): string {
    const { days, hours, minutes, seconds } = convertSeconds(secondsValue);

    const daysFragment = this.evaluateAndFormat(
      days,
      showZeroHours,
      showSuffix ? 'd' : ''
    );
    const hoursFragment = this.evaluateAndFormat(
      hours,
      showZeroHours,
      showSuffix ? 'h' : ''
    );
    const minutesFragment = this.evaluateAndFormat(
      minutes,
      showZeroMinutes,
      showSuffix ? 'm' : ''
    );

    const secondsFragment = `${this.formatValue(seconds)}${
      showSuffix ? 's' : ''
    }`;

    return `${daysFragment}${hoursFragment}${minutesFragment}${secondsFragment}`;
  }

  private formatValue(value: number): string {
    return this.decimalPipe.transform(value, '2.0') ?? '';
  }

  private evaluateAndFormat(
    value: number,
    showZeroValue: boolean,
    suffix: string
  ): string {
    if ((value === 0 && showZeroValue) || value !== 0) {
      return `${this.formatValue(value)}${suffix ? `${suffix} ` : ':'}`;
    }

    return '';
  }
}
